Crate perllsp

Crate perllsp 

Public Cargo facade for the perllsp language server.

Install the server with:

cargo install perllsp

That installs the perllsp binary while delegating the implementation to the perl-lsp-rs crate.

Modules

cancellation
Re-exported cancellation microcrate API.
capability_map
Helpers for translating feature catalog entries into client capability checks. LSP capability/feature translation helpers.
cli
Shared CLI entrypoint for the perl-lsp binaries.
convert
Type conversions between parser engine types and LSP protocol types.
diagnostics_catalog
Backward-compatible re-export of the diagnostic catalog microcrate.
dispatch
Request dispatch placeholder
execute_command
Execute command support for running tests and debugging.
fallback
Fallback implementations
features
LSP feature providers and legacy compatibility modules.
handlers
LSP method handlers
protocol
JSON-RPC protocol types, error handling, and capabilities.
runtime
Full JSON-RPC LSP Server implementation
security
Security module for production hardening
server
LSP Server core
state
Server and document state management
textdoc
Rope-based text document handling for LSP with UTF-16 aware position mapping
transport
LSP transport layer
util
Text processing utilities for LSP

Structs

JsonRpcError
JSON-RPC 2.0 error object
JsonRpcRequest
JSON-RPC 2.0 request message
JsonRpcResponse
JSON-RPC 2.0 response message
LspServer
LSP server that handles JSON-RPC communication

Enums

JsonRpcId
JSON-RPC request/response id.

Functions

run_cli
Run the shared perl-lsp CLI and return the process exit code.
run_stdio
Run the LSP server in stdio mode.