pub struct CodeActionsProvider { /* private fields */ }Expand description
Provides code actions (quick-fixes) for diagnostics
Analyzes Perl source code and diagnostics to provide automated fixes and refactoring actions.
Implementations
Sourceimpl CodeActionsProvider
impl CodeActionsProvider
Sourcepub fn new(source: String) -> CodeActionsProvider
pub fn new(source: String) -> CodeActionsProvider
Sourcepub fn get_code_actions(
&self,
range: (usize, usize),
diagnostics: &[Diagnostic],
) -> Vec<CodeAction>
pub fn get_code_actions( &self, range: (usize, usize), diagnostics: &[Diagnostic], ) -> Vec<CodeAction>
Get all available code actions for a given range