pub struct Diagnostic {
pub range: (usize, usize),
pub severity: DiagnosticSeverity,
pub code: Option<String>,
pub message: String,
pub related_information: Vec<RelatedInformation>,
pub tags: Vec<DiagnosticTag>,
pub suggestion: Option<String>,
}Expand description
A diagnostic message (internal working type).
This is the rich internal type used by the linting machinery. It has string-based codes for compatibility with the diagnostic pipeline.
Fields
range: (usize, usize)Source code range (start, end) where the issue occurs.
severity: DiagnosticSeveritySeverity level of the diagnostic.
code: Option<String>Optional diagnostic code for categorization.
message: StringHuman-readable description of the issue.
Additional context and related information.
Tags for categorizing the diagnostic.
suggestion: Option<String>Optional short suggestion for how to fix the issue.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub fn new(
range: (usize, usize),
severity: DiagnosticSeverity,
message: impl Into<String>,
) -> Diagnostic
pub fn new( range: (usize, usize), severity: DiagnosticSeverity, message: impl Into<String>, ) -> Diagnostic
Creates a diagnostic with required fields and sensible defaults.
Sourcepub fn with_code(self, code: impl Into<String>) -> Diagnostic
pub fn with_code(self, code: impl Into<String>) -> Diagnostic
Sets the optional diagnostic code.
Sourcepub fn with_suggestion(self, suggestion: impl Into<String>) -> Diagnostic
pub fn with_suggestion(self, suggestion: impl Into<String>) -> Diagnostic
Sets the optional suggestion text.
Adds related information to this diagnostic.
Sourcepub fn with_tag(self, tag: DiagnosticTag) -> Diagnostic
pub fn with_tag(self, tag: DiagnosticTag) -> Diagnostic
Adds a tag to this diagnostic.