pub enum SemanticTokenModifier {
Declaration,
Definition,
Reference,
Modification,
Static,
DefaultLibrary,
Async,
Readonly,
Deprecated,
}Expand description
Token modifiers that can be applied to token types
Variants
Declaration
Token is at a declaration site (first introduction)
Definition
Token is at a definition site (same as declaration)
Reference
Token is a reference to a previously declared item
Modification
Token is being modified (e.g., assignment target)
Static
Token is package-level (not lexically scoped)
DefaultLibrary
Token refers to a built-in function or variable
Async
Token is part of an async operation
Readonly
Token is a constant or read-only value
Deprecated
Token refers to a deprecated item
Implementations